<?php

/**
 *
 * @package    EasyAds
 * @author     Abude Bayassi <abude.bayassi@easyads.io>
 * @link       https://www.easyads.io
 * @copyright  2017 EasyAds (https://www.easyads.io)
 * @license    https://www.easyads.io
 * @since      1.0
 */

namespace app\models;

use app\helpers\ImageHelper;
use Yii;
use yii\web\UploadedFile;

/**
 * Class ListingImage
 * @package app\models
 */
class ListingImage extends \app\models\auto\ListingImage
{
    /**
     * Image default width
     */
    CONST IMG_WIDTH = 2000;

    /**
     * Image default height
     */
    CONST IMG_HEIGHT = 2000;

    /**
     * @var
     */
    public $imagesGallery;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['listing_id', 'image_path'], 'required'],
            [['sort'], 'safe'],
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getImage()
    {
        return ImageHelper::resize($this->image_path, self::IMG_WIDTH, self::IMG_HEIGHT);
    }

    /**
     * @param null $adId
     * @throws \Exception
     */
    public function handleUploadedImages($adId = null)
    {
        if($adId == null){
            return;
        }

        if ($this->hasErrors()) {
            return;
        }

        $existingImages = self::find()->where(['listing_id' => $adId])->all();
        if(empty($existingImages)){
            if (!($imagesGallery = UploadedFile::getInstances($this, 'imagesGallery'))) {
                throw new \Exception(t('app', 'Please add at least one image to your ad post'));
            }
        }else{
            if (!($imagesGallery = UploadedFile::getInstances($this, 'imagesGallery'))) {
                return;
            }
        }


        $storagePath = Yii::getAlias('@webroot/uploads/images/listings');
        if (!file_exists($storagePath) || !is_dir($storagePath)) {
            if (!@mkdir($storagePath, 0777, true)) {
                throw new \Exception(t('app', 'The images storage directory({path}) does not exists and cannot be created!'.$storagePath));
            }
        }

        $sort = 0;
        foreach ($imagesGallery as $imageGallery) {

            $sort++;
            $newGalleryImageName = $imageGallery->name;
            if(!$imageGallery->saveAs($storagePath . '/' . $newGalleryImageName)){
                throw new \Exception(t('app', 'Something went wrong while saving images, please try again later.'));
            }
            if (!is_file($storagePath . '/' . $newGalleryImageName)) {
                throw new \Exception(t('app', 'Cannot move the image into the correct storage folder!'));
            }

            $existing_file = $storagePath . '/' . $newGalleryImageName;
            $newGalleryImageName = substr(sha1(time()), 0, 6) . $newGalleryImageName;
            rename($existing_file, $storagePath . '/' . $newGalleryImageName);

            $model = new static();
            $model->image_path = Yii::getAlias('@web/uploads/images/listings/' . $newGalleryImageName);
            $model->listing_id = $adId;
            $model->sort_order = $sort;

            $model->save();
        }
    }
}