<?php
use app\assets\AdAsset;
use yii\bootstrap\ActiveForm;
use kartik\file\FileInput;
use dosamigos\ckeditor\CKEditor;
use app\helpers\FrontendHelper;
use yii\helpers\ArrayHelper;
use app\models\Currency;
use app\models\Country;

AdAsset::register($this);

$script = <<< JS
$(document).ready(function() {
    $('#post-form').yiiActiveForm('add',
        {
            "id":"listingimage-imagesgallery",
            "name":"imagesGallery[]",
            "container":".field-listingimage-imagesgallery",
            "input":"#listingimage-imagesgallery",
            "error":".help-block.help-block-error",
            "validate":function (attribute, value, messages, deferred) {
                if ($('.file-preview-frame').length == 0) {
                    yii.validation.required(value, messages, {"message": $('#post-form').data('err-msg-gallery')});
                }
            }
        }
    );
}); 
JS;

$this->registerJs($script, yii\web\View::POS_LOAD);
?>
<section class="post-listing">
    <div class="container">
        <div class="row">
            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                <?php $listing_id = (int)($action == 'update') ? $ad->listing_id : 0;
                    $form = ActiveForm::begin([
                        'options' => [
                            'enctype' => 'multipart/form-data',
                            'data-listing'   => $listing_id,
                            'data-err-msg-gallery' => t('app', 'Please add at least one image to your ad post')
                        ],
                        'id'        => 'post-form',
                        'method'    => 'post',
                ]); ?>
                <div class="block">
                    <div class="block-heading">
                        <div class="row">
                            <div class="col-lg-8 col-lg-push-2 col-md-8 col-md-push-2 col-sm-12 col-xs-12">
                                <h1><?= ($action == 'update') ? t('app', 'Update your ad') : t('app', 'Post your ad'); ?></h1>
                            </div>
                        </div>
                    </div>
                    <div class="block-body">
                        <div class="row">
                            <div class="col-lg-8 col-lg-push-2 col-md-8 col-md-push-2 col-sm-12 col-xs-12">
                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <?= $form->field($ad, 'title', [
                                            'template'      => '{input} {error}',
                                        ])->textInput([ 'placeholder' => t('app','Title'), 'class' => 'form-control'])->label(false); ?>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <?= $form->field($ad, 'description')->widget(CKEditor::className(), [
                                            'options' => ['rows' => 6],
                                            'preset' => 'basic',
                                            'clientOptions' => [
                                                'removePlugins' => 'notification, clipboard, pastetext, pastefromword, tableselection, toolbar',
                                                'contentsCss' => [Yii::getAlias('@web/assets/site/css/customCkeditor.css')],
                                            ]
                                        ])->label(); ?>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <div class="separator-text">
                                            <span><?=t('app','Choose category');?></span>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 ">
                                        <div class="form-group hidden-xs">
                                            <a href="#" id="choose-class" class="form-control" data-toggle="modal" data-target="#modal-category"><?=t('app', 'Choose category');?></a>
                                        </div>
                                        <div class="form-group hidden-lg hidden-md hidden-sm">
                                            <a href="javascript:;" id="choose-class-m" class="form-control choose-catg-m"><?=t('app', 'Choose category');?></a>
                                        </div>
                                        <?= $form->field($ad, 'category_id', [
                                            'template'      => '{input} {error}',
                                        ])->hiddenInput(['class' => 'form-control'])->label(false); ?>
                                    </div>
                                </div>

                                <div class="modal fade" id="modal-category" tabindex="-1" role="dialog" aria-labelledby="exampleModalLabel" aria-hidden="true">
                                    <div class="modal-dialog add-category" role="document">
                                        <div class="modal-content">
                                            <div class="modal-body">
                                                <div class="choose-category">

                                                    <div class="column-category primary-category">
                                                        <h4>Categories</h4>
                                                        <div class="category-items mCustomScrollbar mCS-autoHide">
                                                            <ul>
                                                                <?php foreach ($categories as $category) {
                                                                    if (empty($category->parent_id)) { ?>
                                                                        <li>
                                                                            <a href="#" data-id="<?=(int)$category->category_id;?>">
                                                                                <span><i class="fa <?=html_encode($category->icon);?>" aria-hidden="true"></i></span>
                                                                                <span><?=html_encode($category->name);?></span>
                                                                            </a>
                                                                        </li>
                                                                <?php
                                                                    }
                                                                }
                                                                ?>
                                                            </ul>
                                                        </div>
                                                    </div>

                                                    <div class="column-subcategory mCustomScrollbar mCS-autoHide">
                                                        <div class="column-subcategory-wrapper">
                                                            <?php $sortedCategories =  \app\helpers\FrontendHelper::getCategoriesSorted($categories);
                                                            foreach ($sortedCategories as $sortedCategoryId=>$sortedCategory) { ?>
                                                                <div class="column-category" data-parent="<?=(int)$sortedCategoryId;?>" style="display: none">
                                                                    <h4><?=html_encode($sortedCategory['name']);?></h4>
                                                                    <div class="category-items mCustomScrollbar mCS-autoHide">
                                                                        <ul>
                                                                            <?php foreach ($sortedCategory['children'] as $childCategory) { ?>
                                                                            <li>
                                                                                <a href="#" data-id="<?=(int)$childCategory->category_id;?>" class="subcateg">
                                                                                    <span><?=html_encode($childCategory->name);?></span>
                                                                                </a>
                                                                            </li>
                                                                            <?php } ?>
                                                                        </ul>
                                                                    </div>
                                                                </div>
                                                            <?php } ?>
                                                        </div>
                                                    </div>

                                                </div>
                                            </div>
                                            <div class="modal-footer">
                                                <div class="row">
                                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                                        <span class="no-category-selected"><?=t('app','Please select a specific category');?></span>
                                                        <button id="success-selection" type="button" class="btn-as" style="display: none" data-dismiss="modal"><?= t('app', 'Submit');?></button>
                                                    </div>
                                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                                        <button id="close-modal" type="button" class="btn-as danger-action pull-right" data-dismiss="modal"><?= t('app', 'Cancel');?></button>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="choose-category-mobile">
                                    <a href="#" class="close-x-categ-m"><i class="fa fa-times" aria-hidden="true"></i></a>
                                    <div class="maincateg-m">
                                        <div class="heading">
                                            <a href="#" class="close-categ-m"><i class="fa fa-arrow-left" aria-hidden="true"></i></a> <?=t('app', 'Choose category');?>
                                        </div>
                                        <ul class="categ-items">
                                            <?php foreach ($categories as $category) {
                                                if (empty($category->parent_id)) { ?>
                                                <li>
                                                    <a href="#" data-id="<?=(int)$category->category_id;?>" class="categ-item-m" data-subcateg="<?= (!empty($category->children)) ? html_encode($category->slug) : '';?>">
                                                        <span><i class="fa <?=html_encode($category->icon);?>" aria-hidden="true"></i></span>
                                                        <span><?=html_encode($category->name);?></span>
                                                    </a>
                                                </li>
                                            <?php
                                                }
                                            }
                                            ?>
                                        </ul>
                                    </div>
                                    <?php $sortedCategories = FrontendHelper::getCategoriesSorted($categories);
                                    foreach ($sortedCategories as $sortedCategoryId=>$sortedCategory) { ?>
                                        <div id="subcateg-<?=html_encode($sortedCategory['slug']);?>" class="subcateg-m">
                                            <div class="heading">
                                                <a href="#" data-parent="<?=(int)$sortedCategoryId;?>" class="back-categ-m">
                                                    <i class="fa fa-arrow-left" aria-hidden="true"></i>
                                                </a>
                                                <?=html_encode($sortedCategory['name']);?>
                                            </div>
                                            <ul class="categ-items">
                                                <?php foreach ($sortedCategory['children'] as $childCategory) { ?>
                                                    <li>
                                                        <a href="#" data-id="<?=(int)$childCategory->category_id;?>" data-subcateg="<?= (!empty($childCategory->children)) ? html_encode($childCategory->slug) : '';?>" class="categ-subitem-m">
                                                            <i class="fa fa-angle-double-right" aria-hidden="true"></i>
                                                            <?=html_encode($childCategory->name);?>
                                                        </a>
                                                    </li>
                                                <?php } ?>
                                            </ul>
                                        </div>
                                    <?php } ?>
                                </div>

                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <div class="separator-text">
                                            <span><?=t('app','Price');?></span>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-4 col-md-4 col-sm-4 col-xs-12">
                                        <?= $form->field($ad, 'currency_id', [
                                            'template'      => '{input} {error}',
                                        ])->dropDownList(ArrayHelper::map(Currency::getActiveCurrencies(), 'currency_id', 'name'),['class'=>'','prompt' => t('app','Currency')])->label(false); ?>
                                    </div>
                                    <div class="col-lg-4 col-md-4 col-sm-4 col-xs-12">
                                        <?= $form->field($ad, 'price', [
                                            'template'      => '{input} {error}',
                                        ])->textInput(['placeholder' => t('app','Price'), 'class' => 'form-control'])->label(false); ?>
                                    </div>
                                    <div class="col-lg-4 col-md-4 col-sm-4 col-xs-12">
                                        <?= $form->field($ad, 'negotiable', [
                                            'options' => [
                                                'class' => 'checkbox'
                                            ],
                                        ])->checkbox(['template' => '{input} {label}'],['value'=>false]); ?>
                                    </div>
                                </div>

                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <div class="separator-text">
                                            <span><?=t('app','Contact details');?></span>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                        <?= $form->field($customer, 'phone', [
                                            'template'      => '{input} {error}',
                                        ])->textInput(['placeholder' => t('app','Phone'), 'class' => 'form-control'])->label(false); ?>
                                    </div>
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                        <?= $form->field($ad, 'hide_phone', [
                                            'options' => [
                                                'class' => 'checkbox'
                                            ],
                                        ])->checkbox(['template' => '{input} {label}'],['value'=>false]); ?>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                        <?= $form->field($customer, 'email', [
                                            'template'      => '{input} {error}',
                                        ])->textInput(['placeholder' => t('app','Email Address'), 'class' => 'form-control'])->label(false); ?>
                                    </div>
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                        <?= $form->field($ad, 'hide_email', [
                                            'options' => [
                                                'class' => 'checkbox'
                                            ],
                                        ])->checkbox(['template' => '{input} {label}'],['value'=>false]); ?>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12">
                                        <?= $form->field($location, 'country_id', [
                                                'template'      => '{input} {error}',
                                            ])->dropDownList(ArrayHelper::map(Country::getActiveCountries(), 'country_id', 'name'),['class'=>'', 'prompt' => t('app','Country'),])->label(false);
                                        ?>
                                    </div>
                                    <div class="col-lg-6 col-md-6 col-sm-6 col-xs-12" id="listing-select-zones-wrapper" data-url="<?=url(['/listing/get-country-zones']);?>" data-zone = <?=(int)$location->zone_id;?>>
                                        <?= $form->field($location, 'zone_id', [
                                            'template'      => '{input} {error}',
                                        ])->dropDownList(array(),['class'=>'','prompt' => t('app','Zone')])->label(false);
                                        ?>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-8 col-md-8 col-sm-8 col-xs-12">
                                        <?= $form->field($location, 'city', [
                                            'template'      => '{input} {error}',
                                        ])->textInput(['placeholder' => t('app','City'), 'class' => 'form-control'])->label(false); ?>
                                    </div>
                                    <div class="col-lg-4 col-md-4 col-sm-4 col-xs-12">
                                        <?= $form->field($location, 'zip', [
                                            'template'      => '{input} {error}',
                                        ])->textInput(['placeholder' => t('app','Zip code'), 'class' => 'form-control'])->label(false); ?>
                                    </div>
                                </div>
                                <div class="row category-fields" style="display: none">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <div class="separator-text">
                                            <span><?=t('app','Category Fields');?></span>
                                        </div>
                                    </div>
                                </div>

                                <div class="row category-fields" id="category-fields" data-url="<?=url(['/listing/get-category-fields']);?>" style="display: none">
                                </div>

                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <div class="separator-text">
                                            <span><?=t('app','Photo Gallery');?></span>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                        <?php
                                        $imagesPreview = [];
                                        $imagesPreviewConfig = [];
                                        if ($action == 'update') {
                                            // sort for images sort_order
                                            usort($uploadedImages, function ($a, $b) { return strnatcmp($a['sort_order'], $b['sort_order']); });
                                            if ($uploadedImages) foreach ($uploadedImages as $key => $image) {
                                                $imagesPreview[] = $image->image_path;
                                                $imagesPreviewConfig[$key]['caption'] = $image->image_path;
                                                $imagesPreviewConfig[$key]['url'] = url(['/listing/remove-ad-image']);
                                                $imagesPreviewConfig[$key]['key'] = $image->image_id;
                                            }
                                        }
                                        echo $form->field($images, 'imagesGallery[]')->widget(FileInput::classname(), [
                                            'options' => [
                                                'multiple' => true,
                                                'class' =>'file-loading',
                                                'data-sort-listing-images' => url(['/listing/sort-ad-images']),
                                            ],
                                            'pluginOptions' => [
                                                'initialPreview'=> $imagesPreview,
                                                'initialPreviewConfig' =>
                                                    $imagesPreviewConfig
                                                ,
                                                'initialPreviewAsData'=>true,
                                                'language' => html_encode(options()->get('app.settings.common.siteLanguage', 'en')),
                                                'deleteUrl' => false,
                                                'uploadUrl' => false,
                                                'allowedFileTypes' => ["image"],
                                                'showUpload' => false,
                                                'showRemove' => false,
                                                'showClose' => false,
                                                'browseOnZoneClick' => true,
                                                'browseClass' => 'btn btn-as',
                                                'removeClass' => 'btn btn-as reverse',
                                                'uploadClass' => 'btn btn-as reverse',
                                                'layoutTemplates' =>
                                                    [
                                                        'footer'=> '<div class="file-thumbnail-footer">' . '{progress} {actions}' . '</div>'
                                                    ],
                                                'fileActionSettings' => [
                                                    'showUpload' => false,
                                                    'showDrag' => true,
                                                ],
                                                'overwriteInitial'=>false,
                                            ]
                                        ])->label(false);
                                        ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="block">
                    <div class="block-body">
                        <div class="row">
                            <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                                <div class="a-center">
                                    <button type="submit" name="post" class="btn-as"><?=t('app','Submit');?></button>
                                    <button type="submit" name="preview" class="btn-as danger-action"><?=t('app','Preview');?></button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php ActiveForm::end(); ?>
            </div>
        </div>
    </div>
</section>

<div class="modal fade" id="modal-post-listing-contact" tabindex="-1" role="dialog" aria-labelledby="" aria-hidden="true">
    <div class="modal-dialog modal-notice" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title"><?=t('app', 'Notice');?></h1>
                <a href="javascript:;" class="x-close" data-dismiss="modal"><i class="fa fa-times" aria-hidden="true"></i></a>
            </div>
            <div class="modal-body">
                <p><?=t('app','Please leave at least one contact option');?></p>
            </div>
            <div class="modal-footer">
                <div class="row">
                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                        <button type="button" class="btn-as black pull-right" data-dismiss="modal">Close</button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>